ggrasp.addRanks: ggrasp.addRanks
Description
adds a rank file to a GGRaSP object. If clusters have been defined, the medoids will be re-defined
Usage
ggrasp.addRanks(x, rank.file)
Arguments
x
the GGRaSP object for which the ranks will be added.
rank.file
string pointing to a file containing the ranks
Value
A GGRaSP object where the ranks have been entirely redefined with the ranks in rank.file