# NOT RUN {
#Getting the ggrasp object
Enter.tree <- ggrasp.load(system.file("extdata", "Enter.kSNP.tree", package="ggrasp"),
file.format = "tree", rank.file =system.file("extdata", "Enter.kSNP.ranks", package="ggrasp"));
# }
# NOT RUN {
Enter.tree.cluster <- ggrasp.cluster(Enter.tree)
# }
# NOT RUN {
#Default examples: using the initizalized ggrasp object will print the newick tree string
print(Enter.tree);
# Using the clustered ggrasp object will print the medoids and their respective clusters
# }
# NOT RUN {
print(Enter.tree.cluster)
# }
# NOT RUN {
#Below are examples of using different output formats and rank levels
# }
# NOT RUN {
print(Enter.tree.cluster, "tree")
# }
# NOT RUN {
print(Enter.tree.cluster, "table", 1)
# }
# NOT RUN {
print(Enter.tree.cluster, "table", 0)
# }
Run the code above in your browser using DataLab